from datetime import date, datetime, time
from typing import Any, Dict, List, Optional, Sequence, Tuple, Union

Scalar = Union[int, float, str, datetime, date, time]
Result = Union[Tuple[Scalar, ...], Dict[str, Scalar]]

class Connection(object):
    def __init__(self, user, password, host, database, timeout, login_timeout, charset, as_dict) -> None: ...
    def autocommit(self, status: bool) -> None: ...
    def close(self) -> None: ...
    def commit(self) -> None: ...
    def cursor(self) -> Cursor: ...
    def rollback(self) -> None: ...

class Cursor(object):
    def __init__(self) -> None: ...
    def __iter__(self): ...
    def __next__(self) -> Any: ...
    def callproc(self, procname: str, **kwargs) -> None: ...
    def close(self) -> None: ...
    def execute(self, stmt: str, params: Optional[Union[Scalar, Tuple[Scalar, ...], Dict[str, Scalar]]]) -> None: ...
    def executemany(self, stmt: str, params: Optional[Sequence[Tuple[Scalar, ...]]]) -> None: ...
    def fetchall(self) -> List[Result]: ...
    def fetchmany(self, size: Optional[int]) -> List[Result]: ...
    def fetchone(self) -> Result: ...

def connect(
    server: Optional[str],
    user: Optional[str],
    password: Optional[str],
    database: Optional[str],
    timeout: Optional[int],
    login_timeout: Optional[int],
    charset: Optional[str],
    as_dict: Optional[bool],
    host: Optional[str],
    appname: Optional[str],
    port: Optional[str],
    conn_properties: Optional[Union[str, Sequence[str]]],
    autocommit: Optional[bool],
    tds_version: Optional[str],
) -> Connection: ...
def get_max_connections() -> int: ...
def set_max_connections(n: int) -> None: ...



from setuptools import setup

name = "types-pymssql"
description = "Typing stubs for pymssql"
long_description = '''
## Typing stubs for pymssql

This is a PEP 561 type stub package for the `pymssql` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `pymssql`. The source for this package can be found at
https://github.com/python/typeshed/tree/master/stubs/pymssql. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/master/README.md for more details.
This package was generated from typeshed commit `b50ebafa7913cf572ed1d4a87926b49f34fd2dc0`.
'''.lstrip()

setup(name=name,
      version="2.1.0",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      install_requires=[],
      packages=['pymssql-python2-stubs'],
      package_data={'pymssql-python2-stubs': ['__init__.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Typing :: Typed",
      ]
)
